import { Injector } from '@angular/core';
import { L10nConfig } from '../models/l10n-config';
import * as i0 from "@angular/core";
/**
 * Implement this class-interface to change the localized path.
 */
export declare abstract class L10nLocation {
    /**
     * This method must contain the logic to get the path.
     * @return The path
     */
    abstract path(): string;
    /**
     * This method must contain the logic to parse the path.
     * @param path The path to be parsed
     * @return The value of language
     */
    abstract parsePath(path: string): string | null;
    /**
     * This method must contain the logic to get the localized segment in the path.
     * @param path The localized path
     */
    abstract getLocalizedSegment(path: string): string | null;
    /**
     * This method must contain the logic to localize the path.
     * @param language The language to add to the path
     * @param path The path to be localized
     */
    abstract toLocalizedPath(language: string, path: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<L10nLocation, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<L10nLocation>;
}
export declare class L10nDefaultLocation implements L10nLocation {
    private config;
    private injector;
    private get location();
    constructor(config: L10nConfig, injector: Injector);
    path(): string;
    parsePath(path: string): string | null;
    getLocalizedSegment(path: string): string | null;
    toLocalizedPath(language: string, path: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<L10nDefaultLocation, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<L10nDefaultLocation>;
}
